/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.introspection.items;

import static java.util.Collections.unmodifiableList;
import static java.util.Collections.unmodifiableSet;

import java.util.Collection;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.fortiss.tooling.kernel.introspection.IIntrospectionDetailsItem;

/**
 * Base class for {@link IIntrospectionDetailsItem}s with class-based handler registrations.
 * <P>
 * The handler key set and the returned handler lists are read-only.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 82D4DEE3356F8B0FB662D08D1E055FC0
 */
public abstract class EObjectAwareIntrospectionDetailsItemBase<T extends Object> implements
		IIntrospectionDetailsItem {

	/** Read-only copy of the services handler list. */
	protected final Map<Class<?>, List<T>> handlerMap;

	/** Constructor. */
	public EObjectAwareIntrospectionDetailsItemBase(Map<Class<?>, List<T>> handlerMap) {
		this.handlerMap = handlerMap;
	}

	/** Returns the first registration classes. */
	public Collection<Class<?>> getHandlerKeyClasses() {
		return unmodifiableSet(handlerMap.keySet());
	}

	/** Returns the handler list for the given registration class. */
	public List<T> getHandlerList(Class<?> regClass) {
		List<T> l = handlerMap.get(regClass);
		return unmodifiableList(l);
	}

	/** Counts all unique handlers. */
	public final int countHandlers() {
		Set<T> handlerSet = new HashSet<T>();
		for(Class<?> c : handlerMap.keySet()) {
			List<T> hlist = handlerMap.get(c);
			if(hlist == null) {
				continue;
			}
			handlerSet.addAll(hlist);
		}
		return handlerSet.size();
	}
}
